@@ -1,21 +1,7 @@
 /*
  *  Copyright 2013-2019  Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of
- *  the License or (at your option) version 3 or any later version
- *  accepted by the membership of KDE e.V. (or its successor approved
- *  by the membership of KDE e.V.), which shall act as a proxy
- *  defined in Section 14 of version 3 of the license.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "trainingsession.h"
@@ -200,14 +186,20 @@ void TrainingSession::selectNextPhrase()
         action->setChecked(false);
     }
     // try to find next phrase, otherwise return completed
+    // 1. case: last phrase in unit
     if (m_indexPhrase >= m_actions.at(m_indexUnit)->actions().count() - 1) {
+        // close current unit
+        emit closeUnit();
         qDebug() << "switching to next unit";
         if (m_indexUnit >= m_actions.count() - 1) {
             emit completed();
         } else {
             ++m_indexUnit;
             m_indexPhrase = 0;
+            // currently there is no way to automatically enter a submenu, at least inform user about new unit
+            m_actions.at(m_indexUnit)->setChecked(true);
         }
+    // 2. case: next phrase inside current unit
     } else {
         ++m_indexPhrase;
     }
